API docs for “spamfighter.txjsonrpc.web.test.test_jsonrpc.TestAuthHeader”

# Class s.t.w.t.t.TestAuthHeader(Test):

Part of spamfighter.txjsonrpc.web.test.test_jsonrpc View Source View In Hierarchy

This is used to get the header info so that we can test authentication.

Method | __init__ | Undocumented
Method | render | Undocumented
Method | jsonrpc_authinfo | Undocumented

Inherited from Test:

Method | jsonrpc_add | This function add two numbers.
Method | jsonrpc_pair | This function puts the two arguments in an array.
Method | jsonrpc_defer | Help for defer.
Method | jsonrpc_deferFail | Undocumented
Method | jsonrpc_fail | Undocumented
Method | jsonrpc_fault | Undocumented
Method | jsonrpc_deferFault | Undocumented
Method | jsonrpc_complex | Undocumented
Method | jsonrpc_dict | Undocumented
Method | _getFunction | Given a string, return a function, or raise jsonrpclib.NoSuchFunction.

Inherited from JSONRPC (via Test):

Method | putSubHandler | Undocumented
Method | getSubHandler | Undocumented
Method | getSubHandlerPrefixes | Undocumented
Method | _cbRender | Undocumented
Method | _ebRender | Undocumented
Method | _listFunctions | Return a list of the names of all jsonrpc methods.

def __init__(self): (source)
overrides spamfighter.txjsonrpc.web.jsonrpc.JSONRPC.__init__
Undocumented
def render(self, request): (source)
overrides spamfighter.txjsonrpc.web.jsonrpc.JSONRPC.render
Undocumented
def jsonrpc_authinfo(self): (source)
Undocumented